package
module
Version:
v0.0.0-...-a6433cc
Opens a new window with list of versions in this module.
Published: Aug 28, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
list

This package implements a structurally-immutable singly linked list.
Documentation
¶
Package list implements a structurally-immutable singly linked list.
type List[T any] struct {
Value T
}
func (l *List[T]) ReverseSlice(dst []T) []T
func (l *List[T]) Slice(dst []T) []T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.